use std::path::PathBuf;
use sqlx::{
    prelude::*,
    sqlite::{
        SqliteConnection,
        SqliteConnectOptions,
        SqliteQueryResult,
    },
};

/// Prepare sqlite database connection
pub async fn connect(path: &PathBuf) -> sqlx::Result<SqliteConnection> {
    let connect_options = SqliteConnectOptions::new()
        .filename(&path)
        .create_if_missing(true);
    SqliteConnection::connect_with(&connect_options).await
}

/// Create tables from template
pub async fn load_template(sqlite_handle: &mut SqliteConnection) -> sqlx::Result<SqliteQueryResult> {
    sqlx::query(concat!(
        include_str!("users.sql"),
        include_str!("security_preferences.sql"),
        include_str!("privacy_preferences.sql"),
        include_str!("notification_preferences.sql"),
        include_str!("external_servers_privacy_preferences.sql"),
        include_str!("external_servers_preferences.sql"),
    )).execute(sqlite_handle).await
}